@@ -13,7 +13,7 @@ use Exporter qw(import);
 
 our @EXPORT = qw(is_holiday holidays);
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0200';
 
 
 sub new {
@@ -31,7 +31,7 @@ sub is_holiday {
 }
 
 
-sub holidays {
+sub us_holidays {
     my ($self, $year) = @_;
     unless ($year) {
       $year = (localtime)[5];
@@ -91,11 +91,18 @@ sub holidays {
     );
     my ($month, $day) = easter($year);
     $holidays{$month}->{$day} = 'Easter';
+    return \%holidays;
+}
+
+
+sub holidays {
+    my ($self, $year) = @_;
+    my $holidays = $self->us_holidays($year);
     my %rtn;
-    for $month (sort { $a <=> $b } keys %holidays) {
-        for $day (sort { $a <=> $b } keys %{ $holidays{$month} }) {
-            $rtn{ sprintf '%02d%02d', $month, $day } = $holidays{$month}->{$day}
-                if $holidays{$month}->{$day};
+    for my $month (sort { $a <=> $b } keys %$holidays) {
+        for my $day (sort { $a <=> $b } keys %{ $holidays->{$month} }) {
+            $rtn{ sprintf '%02d%02d', $month, $day } = $holidays->{$month}->{$day}
+                if $holidays->{$month}->{$day};
         }
     }
     return \%rtn;
@@ -140,11 +147,11 @@ Date::Holidays::USA - Provides United States of America holidays
 
 =head1 VERSION
 
-version 0.0101
+version 0.0200
 
 =head1 SYNOPSIS
 
-  # Using with the Date::Holidays module (recommended):
+  # Using with the Date::Holidays module:
   use Date::Holidays ();
   my $dh = Date::Holidays->new(countrycode => 'USA', nocheck => 1);
   print $dh->is_holiday(year => 2024, month => 1, day => 1), "\n";
@@ -155,15 +162,12 @@ version 0.0101
   $dh = Date::Holidays::USA->new;
   print $dh->is_holiday(2024, 1, 1), "\n";
   $h = $dh->holidays;
+  $h = $dh->us_holidays(2032);
 
 =head1 DESCRIPTION
 
 C<Date::Holidays::USA> provides United States of America holidays.
 
-=head1 NAME
-
-Date::Holidays::USA - Provides United States of America holidays
-
 =head1 METHODS
 
 =head2 new
@@ -184,19 +188,30 @@ Takes three arguments:
 
 Returns the name of the holiday, if one exists on that day.
 
-=head2 holidays
+=head2 us_holidays
 
-  my $holidays = holidays($year);
+  $holidays = us_holidays;
+  $holidays = us_holidays($year);
 
 Returns a hash reference of holiday names, where the keys are by month
 and day.
 
+=head2 holidays
+
+  $holidays = holidays;
+  $holidays = holidays($year);
+
+Returns a hash reference of holiday names, where the keys are 4 digit
+strings month and day.
+
 =head1 SEE ALSO
 
 L<Date::Holidays>
 
 L<Date::Holidays::Adapter>
 
+L<Date::Holidays::Adapter::USA>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
